import { SendSMSParamType } from '../../types/param_types';
import { ApiClientResponse, SendSMSReturnType } from '../../types/return_types';
import { NCPAuthKeyType, SMSserviceAuthType } from '../../types/auth_types';
export declare class SENS {
    private baseUrl;
    /**
     * Get SendSMS Service agent.
     * @access public
     * @param {NCPAuthKeyType} ncpAuthKey NCP API authentication data for using API
     * @param {SMSserviceAuthType} smsAuth Service identification for using SMS Service
     * @returns {SMS} return SMS Service agent
     * @memberof SENS
     */
    smsService(ncpAuthKey: NCPAuthKeyType, smsAuth: SMSserviceAuthType): SMS;
}
declare class SMS {
    /**
     * The account access Key for API authentication
     *
     * @access private
     * @type {ApiClient}
     * @memberof SMS
     */
    private client;
    /**
     * The account access Key for API authentication
     *
     * @access private
     * @type {NCPAuthKeyType}
     * @memberof SMS
     */
    private ncpAuthKey;
    /**
     * The phoneNumber, serviceId for using SMS API
     *
     * @access private
     * @type {SMSserviceAuthType}
     * @memberof SMS
     */
    private smsAuth;
    /**
     * Creates an instance of SMS service agent.
     *
     * @param {string} baseURL The baseURL of each session ( based on service )
     * @param {NCPAuthKeyType} ncpAuthKey NCP API authentication data for using API
     * @param {SMSserviceAuthType} smsAuth Service identification for using SMS Service
     * @memberof SMS
     */
    constructor(baseUrl: string, ncpAuthKey: NCPAuthKeyType, smsAuth: SMSserviceAuthType);
    /**
     * Construct SendSMS Service apiRequest. Generate signature for signing, pass SendSMSParams to body.
     * Single / Multiple send mode supported.
     * @async
     * @access public
     * @param {(SendSMSParamType | SendSMSParamType[])} apiRequest - Message-rㄴeference Data with ( to, content ). Single / Multi value passing supported.
     * @param {(number | undefined)} countryCode - CountryCode for recipient. ( default : 82 )
     * @returns {Promise<ApiClientResponse<SendSMSReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof SMS
     */
    sendSMS(smsParam: SendSMSParamType | SendSMSParamType[], countryCode?: number): Promise<ApiClientResponse<SendSMSReturnType>>;
}
export declare class Project {
}
export {};
