"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Project = exports.SENS = void 0;
const helper_1 = require("../../utils/helper");
const api_request_1 = require("../../utils/api_request");
const baseurl_1 = require("../../shared/baseurl");
class SENS {
    constructor() {
        this.baseUrl = baseurl_1.BaseURL.sens;
    }
    /**
     * Get SendSMS Service agent.
     * @access public
     * @param {NCPAuthKeyType} ncpAuthKey NCP API authentication data for using API
     * @param {SMSserviceAuthType} smsAuth Service identification for using SMS Service
     * @returns {SMS} return SMS Service agent
     * @memberof SENS
     */
    smsService(ncpAuthKey, smsAuth) {
        return new SMS(this.baseUrl, ncpAuthKey, smsAuth);
    }
}
exports.SENS = SENS;
class SMS {
    /**
     * Creates an instance of SMS service agent.
     *
     * @param {string} baseURL The baseURL of each session ( based on service )
     * @param {NCPAuthKeyType} ncpAuthKey NCP API authentication data for using API
     * @param {SMSserviceAuthType} smsAuth Service identification for using SMS Service
     * @memberof SMS
     */
    constructor(baseUrl, ncpAuthKey, smsAuth) {
        this.smsAuth = smsAuth;
        this.ncpAuthKey = ncpAuthKey;
        this.client = new api_request_1.ApiClient(ncpAuthKey, baseUrl);
    }
    /**
     * Construct SendSMS Service apiRequest. Generate signature for signing, pass SendSMSParams to body.
     * Single / Multiple send mode supported.
     * @async
     * @access public
     * @param {(SendSMSParamType | SendSMSParamType[])} apiRequest - Message-rㄴeference Data with ( to, content ). Single / Multi value passing supported.
     * @param {(number | undefined)} countryCode - CountryCode for recipient. ( default : 82 )
     * @returns {Promise<ApiClientResponse<SendSMSReturnType>>} return Promise response of http request with current ApiRequest configs and handle errors
     * @memberof SMS
     */
    async sendSMS(smsParam, countryCode) {
        // construct path and method
        const path = `/sms/v2/services/${this.smsAuth.serviceId}/messages`;
        const method = 'POST';
        // construct signature and headers
        const { timestamp, signature } = helper_1.generateApiSignature({ method: method, url: path, ncpAuthKey: this.ncpAuthKey });
        const headers = {
            'Content-Type': 'application/json; charset=utf-8',
            'x-ncp-iam-access-key': this.ncpAuthKey.accessKey,
            'x-ncp-apigw-timestamp': timestamp,
            'x-ncp-apigw-signature-v2': signature,
        };
        // construct message parameters and body
        countryCode = (countryCode === undefined) ? 82 : countryCode;
        smsParam = (smsParam instanceof Array) ? smsParam : [smsParam];
        const body = {
            'type': 'SMS',
            'contentType': 'COMM',
            'countryCode': `${countryCode}`,
            'from': this.smsAuth.phone,
            'content': ' ',
            'messages': smsParam
        };
        const apiRequest = {
            path: path,
            method: method,
            headers: headers,
            body: body
        };
        return this.client.request(apiRequest);
    }
}
class Project {
}
exports.Project = Project;
